@@ -297,7 +297,7 @@ def create_model(classes, model_name = 'VGG16', classification_model = 'default'
 		if weights_dir_present:
 			try:
 				if weights == 'noisy-student':
-					pretrained_model = efn.EfficientNetB1(weights = noisy_weights['EfficientNetB1', **params)
+					pretrained_model = efn.EfficientNetB1(weights = noisy_weights['EfficientNetB1'], **params)
 				else:
 					pretrained_model = efn.EfficientNetB1(weights = weights_dict['EfficientNetB1'], **params)
 			except:
